@@ -1,8 +1,6 @@
 import json
-
 from requests import Response
-
-from LoginStepHandler import LoginStepHandler
+from .LoginStepHandler import LoginStepHandler
 
 
 class GetPsessionidHandler(LoginStepHandler):
