@@ -1,6 +1,5 @@
 from requests import Response
-
-from LoginStepHandler import LoginStepHandler
+from .LoginStepHandler import LoginStepHandler
 
 
 class GetPtwebqqHandler(LoginStepHandler):
